get static method
Future<PcoCollection<PcoGroupsGroupType> >
get({
- String? id,
- PcoGroupsGroupTypeQuery? query,
- bool getAll = false,
Will get a PcoCollection of PcoGroupsGroupType objects (expecting many)
using a path like this: /groups/v2/group_types
Available Query Filters:
church_center_visiblenot_church_center_visible
Getting a PcoCollection is useful even when retrieving a single object because it contains error data and helper functions.
Additional options may be specified by using the query argument, but some
query options are also available as boolean flags in this function call too.
Implementation
static Future<PcoCollection<PcoGroupsGroupType>> get({
String? id,
PcoGroupsGroupTypeQuery? query,
bool getAll = false,
}) async {
query ??= PcoGroupsGroupTypeQuery();
if (getAll) query.getAll = true;
var url = '/groups/v2/group_types';
if (id != null) url += '/$id';
return PcoCollection.fromApiCall<PcoGroupsGroupType>(url,
query: query, apiVersion: kApiVersion);
}