getAll static method
Will get a PcoCollection containing ALL PcoGroupsGroupType objects (expecting many)
using a path like this: /groups/v2/group_types
Available Query Filters:
church_center_visiblenot_church_center_visible
Additional options may be specified by using the query argument, but some
query options are also available as boolean flags in this function call too.
This function forces the query.getAll to be true.
Implementation
static Future<PcoCollection<PcoGroupsGroupType>> getAll({
String? id,
PcoGroupsGroupTypeQuery? query,
}) async {
query ??= PcoGroupsGroupTypeQuery();
query.getAll = true;
var url = '/groups/v2/group_types';
if (id != null) url += '/$id';
return PcoCollection.fromApiCall<PcoGroupsGroupType>(url,
query: query, apiVersion: kApiVersion);
}