getAllFromGroup static method
Future<PcoCollection<PcoGroupsGroupType> >
getAllFromGroup(
- String groupId, {
- String? id,
- PcoGroupsGroupTypeQuery? query,
Will get a PcoCollection containing ALL PcoGroupsGroupType objects (expecting many)
using a path like this: /groups/v2/groups/$groupId/group_type
Additional options may be specified by using the query argument, but some
query options are also available as boolean flags in this function call too.
This function forces the query.getAll to be true.
Implementation
static Future<PcoCollection<PcoGroupsGroupType>> getAllFromGroup(
String groupId, {
String? id,
PcoGroupsGroupTypeQuery? query,
}) async {
query ??= PcoGroupsGroupTypeQuery();
query.getAll = true;
var url = '/groups/v2/groups/$groupId/group_type';
if (id != null) url += '/$id';
return PcoCollection.fromApiCall<PcoGroupsGroupType>(url,
query: query, apiVersion: kApiVersion);
}